@@ -312,11 +312,11 @@ class Scan:
             progress (:py:attr:`bool`, optional): Show a progress bar. Requires the :py:mod:`tqdm` package. Defaults to :py:attr:`True`.
         """
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
+        to_remove
         for i in iterator:
             im = image.Image(self.data["file"][i], self.data, self.metadata, pixel_maximum=self.pixel_max)
             if im.skip:
-                self.R = np.delete(self.R, i)
-                self.q = np.delete(self.q, i)
+                to_remove.append(i)
                 continue
             if crop_kwargs is None:
                 im.crop(crop_function)
@@ -331,6 +331,8 @@ class Scan:
                 self.n_pixels[i] = None
             else:
                 self.n_pixels[i] = im.n_pixel.n
+        self.R = np.delete(self.R, to_remove)
+        self.q = np.delete(self.q, to_remove)
 
     def footprint_correction(self, beam_width, sample_size):
         """
